﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Windows.Forms;
using HeuristicLab.Common;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;


namespace HeuristicLab.Clients.Hive.Slave.Views {

  [View("HeuristicLab Slave View")]
  [Content(typeof(SlaveItem), IsDefaultView = true)]
  public partial class SlaveView : ItemView {

    public new SlaveItem Content {
      get { return (SlaveItem)base.Content; }
      set {
        if (base.Content != value) {
          base.Content = value;
        }
      }
    }

    public SlaveView() {
      InitializeComponent();
    }

    #region Register Content Events
    protected override void DeregisterContentEvents() {
      Content.SlaveMessageLogged -= new System.EventHandler<EventArgs<string>>(Content_SlaveMessageLogged);
      Content.SlaveShutdown -= new System.EventHandler(Content_SlaveShutdown);
      Content.SlaveStatusChanged -= new System.EventHandler<EventArgs<StatusCommons>>(Content_SlaveStatusChanged);

      base.DeregisterContentEvents();
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();

      Content.SlaveMessageLogged += new System.EventHandler<EventArgs<string>>(Content_SlaveMessageLogged);
      Content.SlaveShutdown += new System.EventHandler(Content_SlaveShutdown);
      Content.SlaveStatusChanged += new System.EventHandler<EventArgs<StatusCommons>>(Content_SlaveStatusChanged);
    }
    #endregion

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        //nothing to do...        
      } else {
        //try to establish a connection to the slave service 
        if (base.Content != null && ((SlaveItem)base.Content).isClosed()) {
          ((SlaveItem)base.Content).Open();
        }
      }
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      //do nothing at the moment, we have nothing editable
    }

    #region Event Handlers
    void Content_SlaveStatusChanged(object sender, EventArgs<StatusCommons> e) {
      txtLog.AppendText("got a status changed object from slave\n");
    }

    void Content_SlaveShutdown(object sender, System.EventArgs e) {
      txtLog.AppendText("Slave did shutdown\n");
    }

    void Content_SlaveMessageLogged(object sender, EventArgs<string> e) {
      txtLog.AppendText(e.Value + "\n");
    }
    #endregion

    private void btnSoftPause_Click(object sender, System.EventArgs e) {
      if (Content != null)
        Content.PauseAll();
    }

    private void btnHardPause_Click(object sender, System.EventArgs e) {
      if (Content != null)
        Content.StopAll();
    }

    private void btnRestart_Click(object sender, System.EventArgs e) {
      if (Content != null)
        Content.RestartCore();
    }

    private void btnSleep_Click(object sender, System.EventArgs e) {
      if (Content != null)
        Content.Sleep();
    }
  }
}
